@@ -103,7 +103,6 @@ PPreview::PPreview( QWidget* parent, ScribusView *vin, ScribusDoc *docu, QString
 	fClip = false;
 	fSpot = true;
 	fGray = false;
-	fICC = false;
 	scaleFactor = 1.0;
 	SMode = 1;
 	getNumericGSVersion(GsMajor, GsMinor);
@@ -283,11 +282,6 @@ PPreview::PPreview( QWidget* parent, ScribusView *vin, ScribusDoc *docu, QString
 	spotColors = new QCheckBox( tr( "Convert Spot Colors" ), jobTitle );
 	Layout1->addWidget( spotColors );
 
-	UseICC = new QCheckBox( tr( "Apply Color Profiles" ), jobTitle );
-	Layout1->addWidget( UseICC );
-	if (!doc->HasCMS)
-		UseICC->setEnabled(false);
-
 	settingsBarLayout->addWidget(jobTitle);
 	QSpacerItem* spacerC = new QSpacerItem( 5, 5, QSizePolicy::Minimum, QSizePolicy::Expanding );
 	settingsBarLayout->addItem( spacerC );
@@ -360,7 +354,6 @@ PPreview::PPreview( QWidget* parent, ScribusView *vin, ScribusDoc *docu, QString
 	EnableGCR->setToolTip( "<qt>" + tr( "A way of switching off some of the gray shades which are composed of cyan, yellow and magenta and using black instead. UCR most affects parts of images which are neutral and/or dark tones which are close to the gray. Use of this may improve printing some images and some experimentation and testing is need on a case by case basis. UCR reduces the possibility of over saturation with CMY inks." ) + "</qt>" );
 	scaleBox->setToolTip( "<qt>" + tr("Resize the scale of the page.") + "</qt>");
 	spotColors->setToolTip("<qt>" + tr( "Enables Spot Colors to be converted to composite colors. Unless you are planning to print spot colors at a commercial printer, this is probably best left enabled." ) + "</qt>");
-	UseICC->setToolTip("<qt>" + tr( "Allows you to embed color profiles in the print stream when color management is enabled" ) + "</qt>");
 
 	//signals and slots
 	connect(AntiAlias, SIGNAL(clicked()), this, SLOT(redisplay()));
@@ -372,7 +365,6 @@ PPreview::PPreview( QWidget* parent, ScribusView *vin, ScribusDoc *docu, QString
 	connect(ClipMarg, SIGNAL(clicked()), this, SLOT(redisplay()));
 	connect(spotColors, SIGNAL(clicked()), this, SLOT(redisplay()));
 	connect(useGray, SIGNAL(clicked()), this, SLOT(redisplay()));
-	connect(UseICC, SIGNAL(clicked()), this, SLOT(redisplay()));
 	if (!HaveTiffSep)
 	{
 		connect(EnableCMYK_C, SIGNAL(clicked()), this, SLOT(ToggleCMYK_Colour()));
@@ -401,11 +393,6 @@ void PPreview::setValues()
 		ClipMarg->setChecked(doc->Print_Options.doClip);
 		spotColors->setChecked(!doc->Print_Options.useSpotColors);
 		useGray->setChecked(!doc->Print_Options.useColor);
-		if (doc->HasCMS)
-		{
-			UseICC->setChecked( postscriptPreview ? doc->Print_Options.useICC : false);
-			UseICC->setEnabled( postscriptPreview );
-		}
 	}
 	else
 	{
@@ -420,11 +407,6 @@ void PPreview::setValues()
 			useGray->setChecked(true);
 		else
 			useGray->setChecked(false);
-		if (doc->HasCMS)
-		{
-			UseICC->setChecked( postscriptPreview ? prefs->getBool("ICCinUse", false) : false);
-			UseICC->setEnabled( postscriptPreview );
-		}
 	}
 }
 
@@ -566,7 +548,6 @@ int PPreview::RenderPreview(int Seite, int Res)
 		options.separationName = "All";
 		options.toFile = false;
 		options.useColor = !useGray->isChecked();
-		options.useICC = false;
 		options.useSpotColors = false;
 		bool done = winPrint.gdiPrintPreview(doc, page, &image, options, Res / 72.0);
 		if ( done )
@@ -577,13 +558,10 @@ int PPreview::RenderPreview(int Seite, int Res)
 	// Recreate Postscript-File only when the actual Page has changed
 	if ((Seite != APage)  || (EnableGCR->isChecked() != GMode)  || (useGray->isChecked() != fGray)
 		|| (MirrorHor->isChecked() != mHor) || (MirrorVert->isChecked() != mVer) || (ClipMarg->isChecked() != fClip)
-		|| (UseICC->isChecked() != fICC)    || (spotColors->isChecked() != fSpot))
+		|| (spotColors->isChecked() != fSpot))
 	{
 		ReallyUsed.clear();
 		doc->getUsedFonts(ReallyUsed);
-		bool useIC = UseICC->isChecked();
-		if (!doc->HasCMS)
-			useIC = false;
 		PrintOptions options;
 		options.pageNumbers.push_back(Seite+1);
 		options.outputSeparations = false;
@@ -592,7 +570,6 @@ int PPreview::RenderPreview(int Seite, int Res)
 		options.useColor = !useGray->isChecked();
 		options.mirrorH = MirrorHor->isChecked();
 		options.mirrorV = MirrorVert->isChecked();
-		options.useICC = useIC;
 		options.doGCR = EnableGCR->isChecked();
 		options.setDevParam = false;
 		options.doClip = ClipMarg->isChecked();
@@ -650,6 +627,22 @@ int PPreview::RenderPreview(int Seite, int Res)
 		args.append( "-dTextAlphaBits=4" );
 		args.append( "-dGraphicsAlphaBits=4" );
 	}
+	if ((doc->HasCMS) && (GsMinor >= 0) && (GsMajor >= 9))
+	{
+		args.append("-sDefaultCMYKProfile=" + QDir::toNativeSeparators(doc->DocPrinterProf.profilePath()));
+		if (EnableCMYK->isChecked() && HaveTiffSep)
+			args.append("-sOutputICCProfile=" + QDir::toNativeSeparators(doc->DocPrinterProf.profilePath()));
+		else
+			args.append("-sOutputICCProfile=" + QDir::toNativeSeparators(doc->DocOutputProf.profilePath()));
+	}
+	else if (ScCore->haveCMS() && (GsMinor >= 0) && (GsMajor >= 9))
+	{
+		args.append("-sDefaultCMYKProfile=" + QDir::toNativeSeparators(ScCore->defaultCMYKProfile.profilePath()));
+		if (EnableCMYK->isChecked() && HaveTiffSep)
+			args.append("-sOutputICCProfile=" + QDir::toNativeSeparators(ScCore->defaultCMYKProfile.profilePath()));
+		else
+			args.append("-sOutputICCProfile=" + QDir::toNativeSeparators(ScCore->defaultRGBProfile.profilePath()));
+	}
 	// Add any extra font paths being used by Scribus to gs's font search path
 	PrefsContext *pc = prefsManager->prefsFile->getContext("Fonts");
 	PrefsTable *extraFonts = pc->getTable("ExtraFontDirs");
@@ -658,7 +651,7 @@ int PPreview::RenderPreview(int Seite, int Res)
 		cmd1 = QString("-sFONTPATH=%1").arg(QDir::toNativeSeparators(extraFonts->get(0,0)));
 	for (int i = 1; i < extraFonts->getRowCount(); ++i)
 		cmd1 += QString("%1%2").arg(sep).arg(QDir::toNativeSeparators(extraFonts->get(i,0)));
-	if( !cmd1.isEmpty() )
+	if (!cmd1.isEmpty())
 		args.append( cmd1 );
 	// then add any final args and call gs
 	if ((EnableCMYK->isChecked()) && HaveTiffSep)
@@ -683,13 +676,10 @@ int PPreview::RenderPreviewSep(int Seite, int Res)
 	// Recreate Postscript-File only when the actual Page has changed
 	if ((Seite != APage)  || (EnableGCR->isChecked() != GMode) || (useGray->isChecked() != fGray)
 		|| (MirrorHor->isChecked() != mHor) || (MirrorVert->isChecked() != mVer) || (ClipMarg->isChecked() != fClip)
-		|| (UseICC->isChecked() != fICC) || (spotColors->isChecked() != fSpot))
+		|| (spotColors->isChecked() != fSpot))
 	{
 		ReallyUsed.clear();
 		doc->getUsedFonts(ReallyUsed);
-		bool useIC = UseICC->isChecked();
-		if (!doc->HasCMS)
-			useIC = false;
 		PrintOptions options;
 		options.pageNumbers.push_back(Seite+1);
 		options.outputSeparations = false;
@@ -698,7 +688,6 @@ int PPreview::RenderPreviewSep(int Seite, int Res)
 		options.useColor = !useGray->isChecked();
 		options.mirrorH = MirrorHor->isChecked();
 		options.mirrorV = MirrorVert->isChecked();
-		options.useICC = useIC;
 		options.doGCR = EnableGCR->isChecked();
 		options.setDevParam = false;
 		options.doClip = ClipMarg->isChecked();
@@ -738,6 +727,16 @@ int PPreview::RenderPreviewSep(int Seite, int Res)
 		args1.append("-dTextAlphaBits=4");
 		args1.append("-dGraphicsAlphaBits=4");
 	}
+	if ((doc->HasCMS) && (GsMinor >= 0) && (GsMajor >= 9))
+	{
+		args1.append("-sDefaultCMYKProfile=" + QDir::toNativeSeparators(doc->DocPrinterProf.profilePath()));
+		args1.append("-sOutputICCProfile=" + QDir::toNativeSeparators(doc->DocPrinterProf.profilePath()));
+	}
+	else if (ScCore->haveCMS() && (GsMinor >= 0) && (GsMajor >= 9))
+	{
+		args1.append("-sDefaultCMYKProfile=" + QDir::toNativeSeparators(ScCore->defaultCMYKProfile.profilePath()));
+		args1.append("-sOutputICCProfile=" + QDir::toNativeSeparators(ScCore->defaultCMYKProfile.profilePath()));
+	}
 	// Add any extra font paths being used by Scribus to gs's font search path
 	PrefsContext *pc = prefsManager->prefsFile->getContext("Fonts");
 	PrefsTable *extraFonts = pc->getTable("ExtraFontDirs");
@@ -746,7 +745,7 @@ int PPreview::RenderPreviewSep(int Seite, int Res)
 		cmd = QString("-sFONTPATH=%1").arg(QDir::toNativeSeparators(extraFonts->get(0,0)));
 	for (int i = 1; i < extraFonts->getRowCount(); ++i)
 		cmd += QString("%1%2").arg(sep).arg(QDir::toNativeSeparators(extraFonts->get(i,0)));
-	if( !cmd.isEmpty() )
+	if (!cmd.isEmpty())
 		args1.append( cmd );
 	args1.append( QString("-sOutputFile=%1").arg(QDir::toNativeSeparators(ScPaths::getTempFileDir()+"/sc.tif")) );
 
@@ -914,7 +913,7 @@ QPixmap PPreview::CreatePreview(int Seite, int Res)
 	        || (AntiAlias->isChecked() != GsAl) || (((AliasTr->isChecked() != Trans) || (EnableGCR->isChecked() != GMode))
 			&& (!EnableCMYK->isChecked()))
 			 || (useGray->isChecked() != fGray) || (MirrorHor->isChecked() != mHor) || (MirrorVert->isChecked() != mVer)
-			 || (ClipMarg->isChecked() != fClip) || (UseICC->isChecked() != fICC) || (spotColors->isChecked() != fSpot))
+			 || (ClipMarg->isChecked() != fClip) || (spotColors->isChecked() != fSpot))
 	{
 		if (!EnableCMYK->isChecked() || (!HaveTiffSep))
 		{
@@ -937,7 +936,7 @@ QPixmap PPreview::CreatePreview(int Seite, int Res)
 			if ((Seite != APage) || (EnableCMYK->isChecked() != CMode) || (SMode != scaleBox->currentIndex())
 	       	 || (AntiAlias->isChecked() != GsAl) || (AliasTr->isChecked() != Trans) || (EnableGCR->isChecked() != GMode)
 	       	 || (useGray->isChecked() != fGray)  || (MirrorHor->isChecked() != mHor)|| (MirrorVert->isChecked() != mVer)
-	       	 || (ClipMarg->isChecked() != fClip) || (UseICC->isChecked() != fICC) || (spotColors->isChecked() != fSpot))
+	       	 || (ClipMarg->isChecked() != fClip) || (spotColors->isChecked() != fSpot))
 			{
 				ret = RenderPreviewSep(Seite, Res);
 				if (ret > 0)
@@ -954,10 +953,10 @@ QPixmap PPreview::CreatePreview(int Seite, int Res)
 				std::swap(w, h2);
 			image = QImage(w, h2, QImage::Format_ARGB32);
 			QRgb clean = qRgba(0, 0, 0, 0);
-			for( int yi=0; yi < h2; ++yi )
+			for (int yi=0; yi < h2; ++yi)
 			{
 				QRgb *q = (QRgb*)(image.scanLine( yi ));
-				for(int xi=0; xi < w; ++xi )
+				for (int xi=0; xi < w; ++xi)
 				{
 					*q = clean;
 					q++;
@@ -1067,10 +1066,10 @@ QPixmap PPreview::CreatePreview(int Seite, int Res)
 			if (EnableInkCover->isChecked())
 			{
 				uint limitVal = (CoverThresholdValue->value() * 255) / 100;
-				for( int yi=0; yi < h2; ++yi )
+				for (int yi=0; yi < h2; ++yi)
 				{
 					QRgb *q = (QRgb*)(image.scanLine( yi ));
-					for(int xi=0; xi < w; ++xi )
+					for (int xi=0; xi < w; ++xi)
 					{
 						uint greyVal = *q;
 						if (greyVal != 0)
@@ -1101,12 +1100,17 @@ QPixmap PPreview::CreatePreview(int Seite, int Res)
 			}
 			else
 			{
-				if (doc->HasCMS)
+				if (doc->HasCMS || ScCore->haveCMS())
 				{
 					QRgb alphaFF = qRgba(0,0,0,255);
 					QRgb alphaOO = qRgba(255,255,255,0);
-					ScColorTransform transCMYK = ScColorMgmtEngine::createTransform(doc->DocPrinterProf, Format_YMCK_8, doc->DocOutputProf, Format_BGRA_8, Intent_Relative_Colorimetric, Ctf_LowResPrecalc);
-					for( int yi=0; yi < h2; ++yi )
+					int flags = Ctf_LowResPrecalc;
+					if ((doc->HasCMS && doc->CMSSettings.BlackPoint) || (!doc->HasCMS))
+						flags |= Ctf_BlackPointCompensation;
+					ScColorProfile cmykProfile = doc->HasCMS ? doc->DocPrinterProf : ScCore->defaultCMYKProfile;
+					ScColorProfile rgbProfile  = doc->HasCMS ? doc->DocOutputProf : ScCore->defaultRGBProfile;
+					ScColorTransform transCMYK = ScColorMgmtEngine::createTransform(cmykProfile, Format_YMCK_8, rgbProfile, Format_BGRA_8, Intent_Relative_Colorimetric, flags);
+					for (int yi=0; yi < h2; ++yi)
 					{
 						uchar* ptr = image.scanLine( yi );
 						transCMYK.apply(ptr, ptr, image.width());
@@ -1130,10 +1134,10 @@ QPixmap PPreview::CreatePreview(int Seite, int Res)
 				}
 				else
 				{
-					for( int yi=0; yi < h2; ++yi )
+					for (int yi=0; yi < h2; ++yi)
 					{
 						QRgb *q = (QRgb*)(image.scanLine( yi ));
-						for(int xi=0; xi < w; ++xi )
+						for (int xi=0; xi < w; ++xi)
 						{
 							cyan = qRed(*q);
 							magenta = qGreen(*q);
@@ -1162,11 +1166,16 @@ QPixmap PPreview::CreatePreview(int Seite, int Res)
 			QFile f(ScPaths::getTempFileDir()+"/sc.png");
 			if (f.open(QIODevice::ReadOnly))
 			{
-				if (doc->HasCMS)
+				if (doc->HasCMS || ScCore->haveCMS())
 				{
 					QRgb alphaFF = qRgba(0,0,0,255);
 					QRgb alphaOO = qRgba(255,255,255,0);
-					ScColorTransform transCMYK = ScColorMgmtEngine::createTransform(doc->DocPrinterProf, Format_YMCK_8, doc->DocOutputProf, Format_BGRA_8, Intent_Relative_Colorimetric, Ctf_LowResPrecalc);
+					int flags = Ctf_LowResPrecalc;
+					if ((doc->HasCMS && doc->CMSSettings.BlackPoint) || (!doc->HasCMS))
+						flags |= Ctf_BlackPointCompensation;
+					ScColorProfile cmykProfile = doc->HasCMS ? doc->DocPrinterProf : ScCore->defaultCMYKProfile;
+					ScColorProfile rgbProfile  = doc->HasCMS ? doc->DocOutputProf : ScCore->defaultRGBProfile;
+					ScColorTransform transCMYK = ScColorMgmtEngine::createTransform(cmykProfile, Format_YMCK_8, rgbProfile, Format_BGRA_8, Intent_Relative_Colorimetric, flags);
 					for (int y=0; y < h2; ++y )
 					{
 						uchar* ptr = image.scanLine( y );
@@ -1258,12 +1267,12 @@ QPixmap PPreview::CreatePreview(int Seite, int Res)
 		{
 			int wi = image.width();
 			int hi = image.height();
-			for( int yi=0; yi < hi; ++yi )
+			for (int yi=0; yi < hi; ++yi)
 			{
 				QRgb *s = (QRgb*)(image.scanLine( yi ));
-				for(int xi=0; xi < wi; ++xi )
+				for (int xi=0; xi < wi; ++xi)
 				{
-					if((*s) == 0xffffffff)
+					if ((*s) == 0xffffffff)
 						(*s) &= 0x00ffffff;
 					s++;
 				}
@@ -1295,11 +1304,11 @@ QPixmap PPreview::CreatePreview(int Seite, int Res)
 bool PPreview::usePostscriptPreview(QString printerName, PrintEngine engine)
 {
 #ifdef _WIN32
-	if ( printerName == tr("File") )
+	if (printerName == tr("File"))
 		return true;
-	else if( printerName.isEmpty() )
+	else if (printerName.isEmpty())
 		return PrinterUtil::isPostscriptPrinter( ScPrintEngine_GDI::getDefaultPrinter() );
-	else if( engine >= PostScript1 && engine <= PostScript3 )
+	else if (engine >= PostScript1 && engine <= PostScript3)
 		return PrinterUtil::isPostscriptPrinter( printerName );
 	return false;
 #else
@@ -1322,7 +1331,6 @@ void PPreview::getUserSelection(int page)
 	fClip = ClipMarg->isChecked();
 	fSpot = spotColors->isChecked();
 	fGray = useGray->isChecked();
-	fICC = UseICC->isChecked();
 }
 
 void PPreview::imageLoadError(QPixmap &Bild, int page)
